(********************************************************************
 * COPYRIGHT --  
 ********************************************************************
 * Package: ACP10
 * File: ACP10.typ
 * Author: lin
 * Created: December 29, 2011
 ********************************************************************
 * Data types of package ACP10
 ********************************************************************)
(****Servo axis type*)
(**Structure for message text*)

TYPE
	messageText_typ : 	STRUCT 
		line_01 : STRING[80];
		line_02 : STRING[80];
		line_03 : STRING[80];
		line_04 : STRING[80];
	END_STRUCT;
END_TYPE

(**Structure to define servo command*)

TYPE
	servoCmd_typ : 	STRUCT 
		homing : BOOL;
		ctrlOn : BOOL;
		ctrlOff : BOOL;
		basisMoveInit : BOOL;
		moveStop : BOOL;
		moveE_Stop : BOOL;
		relMove : BOOL;
		absMove : BOOL;
		posMove : BOOL;
		negMove : BOOL;
		posJog : BOOL;
		negJog : BOOL;
		startCAM : BOOL;
		restartCAM : BOOL;
		stopCAM : BOOL;
		errAck : BOOL;
	END_STRUCT;
END_TYPE

(**Structure for monitor servo status*)

TYPE
	servoMonitor_typ : 	STRUCT 
		errOutput : BOOL;
		homeRdy : USINT;
		ctrlRdy : USINT;
		inPosi : USINT;
		step : UINT;
		errStep : UINT;
		errID : UINT;
		moveMode : UINT;
		actVel : DINT;
		actPosi : DINT;
		axisObj : UDINT; (*Get  the pointer of ACP10AXIS_typ structure*)
		strEng : STRING[80]; (*Axis step explain*)
		errInfo : STRING[80];
		messageText : messageText_typ; (*Error message(english)*)
	END_STRUCT;
END_TYPE

(**Structure for controller parameter*)

TYPE
	servoPara_typ : 	STRUCT 
		countDir : BOOL; (*Count direction. 0="ncSTANDARD" ; 1= "ncINVERSE"*)
		velPos : DINT; (*Units/s*)
		velNeg : DINT; (*Units/s*)
		jogVelPos : DINT; (*Units/s*)
		jogVelNeg : DINT; (*Units/s*)
		accPos : DINT; (*Units/s*)
		decPos : DINT; (*Units/s*)
		accNeg : DINT; (*Units/s*)
		decNeg : DINT; (*Units/s*)
		homMode : USINT; (*Speed for searching the reference switch*)
		homVelTrigger : USINT; (*Trigger Speed*)
		homEdgeSW : USINT; (*Edge of reference switch*)
		homStartDir : USINT; (*Start direction*)
		homTriggDir : USINT; (*Trigger direction*)
	END_STRUCT;
END_TYPE

(**Structure for config servo para*)

TYPE
	servoConfig_typ : 	STRUCT 
		basisOvrd_v : UINT := 10000; (*10000=100%(0~10000)*)
		basisOvrd_a : UINT := 10000; (*10000=100%(0~10000)*)
		velPos : DINT; (*Units/s*)
		velNeg : DINT; (*Units/s*)
		jogVelPos : DINT; (*Units/s*)
		jogVelNeg : DINT; (*Units/s*)
		relVel : DINT; (*Units/s*)
		relPosi : DINT; (*Units*)
		absVel : DINT; (*Units/s*)
		absPosi : DINT; (*Units*)
		homeRefPosi : DINT := 0; (*Reference position[Units]*)
	END_STRUCT;
END_TYPE

(**Servo axis control structure*)

TYPE
	axis_typ : 	STRUCT 
		cmd : servoCmd_typ;
		para : servoPara_typ;
		monitor : servoMonitor_typ;
		config : servoConfig_typ;
		axisObjName : STRING[32];
		downParaName : ARRAY[0..ACP10_MAX_PARA_NR_MINUSED_ONE]OF STRING[32];
	END_STRUCT;
END_TYPE
